@@ -194,9 +194,9 @@ class Extras(Structure):
         clibreboundx.rebx_gr_potential_potential.restype = c_double
         return clibreboundx.rebx_gr_potential_potential(byref(self), byref(force))
 
-    def tides_constant_time_lag_potential(self, force):
+    def tides_constant_time_lag_potential(self):
         clibreboundx.rebx_tides_constant_time_lag_potential.restype = c_double
-        return clibreboundx.rebx_tides_constant_time_lag_potential(byref(self), byref(force))
+        return clibreboundx.rebx_tides_constant_time_lag_potential(byref(self))
 
     def tides_spin_energy(self):
         clibreboundx.rebx_tides_spin_energy.restype = c_double
@@ -228,9 +228,8 @@ class Extras(Structure):
         Returns a list of the three (x,y,z) components of the spin angular momentum of all particles in the simulation with
         moment of inertia (I) and spin angular frequency vector (Omega) parameters set.
         """
-        clibreboundx.rebx_spin_angular_momentum.restype = rebound.Vec3d
-        L = clibreboundx.rebx_spin_angular_momentum(byref(self))
-        return [L.x, L.y, L.z]
+        clibreboundx.rebx_tools_spin_angular_momentum.restype = rebound._Vec3d
+        return rebound.Vec3d(clibreboundx.rebx_tools_spin_angular_momentum(byref(self)))
 
     def process_messages(self):
         try:
@@ -367,7 +366,7 @@ Interpolator._fields_ = [  ("interpolation", c_int),
 INTERPOLATION_TYPE = {"none":0, "spline":1}
 
 # This list keeps pairing from C rebx_param_type enum to ctypes type 1-to-1. Derive the required mappings from it
-REBX_C_TO_CTYPES = [["REBX_TYPE_NONE", None], ["REBX_TYPE_DOUBLE", c_double], ["REBX_TYPE_INT",c_int], ["REBX_TYPE_POINTER", c_void_p], ["REBX_TYPE_FORCE", Force], ["REBX_TYPE_UNIT32", c_uint32], ["REBX_TYPE_ORBIT", rebound.Orbit], ["REBX_TYPE_ODE", rebound.ODE], ["REBX_TYPE_VEC3D", rebound.Vec3d]]
+REBX_C_TO_CTYPES = [["REBX_TYPE_NONE", None], ["REBX_TYPE_DOUBLE", c_double], ["REBX_TYPE_INT",c_int], ["REBX_TYPE_POINTER", c_void_p], ["REBX_TYPE_FORCE", Force], ["REBX_TYPE_UNIT32", c_uint32], ["REBX_TYPE_ORBIT", rebound.Orbit], ["REBX_TYPE_ODE", rebound.ODE], ["REBX_TYPE_VEC3D", rebound._Vec3d]]
 REBX_CTYPES = {} # maps int value of rebx_param_type enum to ctypes type
 REBX_C_PARAM_TYPES = {} # maps string of rebx_param_type enum to int
 for i, pair in enumerate(REBX_C_TO_CTYPES):
