@@ -64,7 +64,7 @@
 #include "reboundx.h"
 
 void rebx_track_min_distance(struct reb_simulation* const sim, struct rebx_operator* const operator, const double dt){
-    const struct rebx_extras* const rebx = sim->extras;
+    struct rebx_extras* const rebx = sim->extras;
     const int N = sim->N - sim->N_var;
     for(int i=0; i<N; i++){
         struct reb_particle* const p = &sim->particles[i];
